fedex.services.rate_service

Package fedex :: Package services :: Module rate_service |
[hide private]
[frames] | no frames]

# Module rate_service

source code

# Rate Service Module

This package contains classes to request pre-ship rating information and to determine estimated or courtesy billing quotes. Time in Transit can be returned with the rates if it is specified in the request.

Classes | [hide private]
| FedexRateServiceRequest This class allows you to get the shipping charges for a particular address.

Variables | [hide private]
| __package__ = ``'``fedex.services``'``